@@ -1,4 +1,4 @@
-// $Id: vserver-internal.h,v 1.1.4.11 2003/12/30 14:07:03 ensc Exp $    --*- c++ -*--
+// $Id: vserver-internal.h,v 1.1.4.12 2004/01/07 16:22:59 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -40,7 +40,7 @@
 #  define VC_SELECT(ID)	case ID: if(1)
 #  define CALL_VC(...)					\
   switch (utilvserver_checkCompatVersion()&~0xff) {	\
-    case -1	:  if (1) break;			\
+    case -1 & 0xff	:  if (1) break;		\
       VC_SUFFIX, __VA_ARGS__ , VC_PREFIX;		\
     default	:  errno = EINVAL;			\
   }							\
